alligator.exceptions — Alligator 0.5.0-dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- Alligator 0.5.0-dev documentation »

# alligator.exceptions

exception `alligator.exceptions.` `AlligatorException`

  A base exception for all Alligator errors.

exception `alligator.exceptions.` `TaskFailed`

  Raised when a task fails.

exception `alligator.exceptions.` `UnknownCallableError`

  Thrown when trying to import an unknown attribute from a module for a task.

exception `alligator.exceptions.` `UnknownModuleError`

  Thrown when trying to import an unknown module for a task.

### Navigation

- index
- modules |
- next |
- previous |
- Alligator 0.5.0-dev documentation »